Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=mlengine.gcp.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type DefaultVersionObservation
- type DefaultVersionParameters
- type Model
- func (in *Model) DeepCopy() *Model
- func (in *Model) DeepCopyInto(out *Model)
- func (in *Model) DeepCopyObject() runtime.Object
- func (mg *Model) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Model) GetConnectionDetailsMapping() map[string]string
- func (mg *Model) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Model) GetID() string
- func (tr *Model) GetObservation() (map[string]any, error)
- func (tr *Model) GetParameters() (map[string]any, error)
- func (mg *Model) GetProviderConfigReference() *xpv1.Reference
- func (mg *Model) GetProviderReference() *xpv1.Reference
- func (mg *Model) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Model) GetTerraformResourceType() string
- func (tr *Model) GetTerraformSchemaVersion() int
- func (mg *Model) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Model) LateInitialize(attrs []byte) (bool, error)
- func (mg *Model) SetConditions(c ...xpv1.Condition)
- func (mg *Model) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *Model) SetObservation(obs map[string]any) error
- func (tr *Model) SetParameters(params map[string]any) error
- func (mg *Model) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Model) SetProviderReference(r *xpv1.Reference)
- func (mg *Model) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Model) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ModelList
- type ModelObservation
- type ModelParameters
- type ModelSpec
- type ModelStatus
Constants ¶
const ( CRDGroup = "mlengine.gcp.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( Model_Kind = "Model" Model_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Model_Kind}.String() Model_KindAPIVersion = Model_Kind + "." + CRDGroupVersion.String() Model_GroupVersionKind = CRDGroupVersion.WithKind(Model_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type DefaultVersionObservation ¶
type DefaultVersionObservation struct {
}
func (*DefaultVersionObservation) DeepCopy ¶
func (in *DefaultVersionObservation) DeepCopy() *DefaultVersionObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DefaultVersionObservation.
func (*DefaultVersionObservation) DeepCopyInto ¶
func (in *DefaultVersionObservation) DeepCopyInto(out *DefaultVersionObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DefaultVersionParameters ¶
type DefaultVersionParameters struct {
// The name specified for the version when it was created.
// +kubebuilder:validation:Required
Name *string `json:"name" tf:"name,omitempty"`
}
func (*DefaultVersionParameters) DeepCopy ¶
func (in *DefaultVersionParameters) DeepCopy() *DefaultVersionParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DefaultVersionParameters.
func (*DefaultVersionParameters) DeepCopyInto ¶
func (in *DefaultVersionParameters) DeepCopyInto(out *DefaultVersionParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Model ¶
type Model struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ModelSpec `json:"spec"`
Status ModelStatus `json:"status,omitempty"`
}
Model is the Schema for the Models API. Represents a machine learning solution. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,gcp}
func (*Model) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Model.
func (*Model) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Model) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Model) GetCondition ¶
func (mg *Model) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Model.
func (*Model) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Model
func (*Model) GetDeletionPolicy ¶
func (mg *Model) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Model.
func (*Model) GetObservation ¶
GetObservation of this Model
func (*Model) GetParameters ¶
GetParameters of this Model
func (*Model) GetProviderConfigReference ¶
GetProviderConfigReference of this Model.
func (*Model) GetProviderReference ¶
GetProviderReference of this Model. Deprecated: Use GetProviderConfigReference.
func (*Model) GetPublishConnectionDetailsTo ¶
func (mg *Model) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Model.
func (*Model) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Model
func (*Model) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Model) GetWriteConnectionSecretToReference ¶
func (mg *Model) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Model.
func (*Model) LateInitialize ¶
LateInitialize this Model using its observed tfState. returns True if there are any spec changes for the resource.
func (*Model) SetConditions ¶
SetConditions of this Model.
func (*Model) SetDeletionPolicy ¶
func (mg *Model) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Model.
func (*Model) SetObservation ¶
SetObservation for this Model
func (*Model) SetParameters ¶
SetParameters for this Model
func (*Model) SetProviderConfigReference ¶
SetProviderConfigReference of this Model.
func (*Model) SetProviderReference ¶
SetProviderReference of this Model. Deprecated: Use SetProviderConfigReference.
func (*Model) SetPublishConnectionDetailsTo ¶
func (mg *Model) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Model.
func (*Model) SetWriteConnectionSecretToReference ¶
func (mg *Model) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Model.
type ModelList ¶
type ModelList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Model `json:"items"`
}
ModelList contains a list of Models
func (*ModelList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelList.
func (*ModelList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ModelList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ModelObservation ¶
type ModelObservation struct {
// an identifier for the resource with format projects/{{project}}/models/{{name}}
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*ModelObservation) DeepCopy ¶
func (in *ModelObservation) DeepCopy() *ModelObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelObservation.
func (*ModelObservation) DeepCopyInto ¶
func (in *ModelObservation) DeepCopyInto(out *ModelObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelParameters ¶
type ModelParameters struct {
// The default version of the model. This version will be used to handle
// prediction requests that do not specify a version.
// Structure is documented below.
// +kubebuilder:validation:Optional
DefaultVersion []DefaultVersionParameters `json:"defaultVersion,omitempty" tf:"default_version,omitempty"`
// The description specified for the model when it was created.
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// One or more labels that you can add, to organize your models.
// +kubebuilder:validation:Optional
Labels map[string]*string `json:"labels,omitempty" tf:"labels,omitempty"`
// The name specified for the model.
// +kubebuilder:validation:Required
Name *string `json:"name" tf:"name,omitempty"`
// If true, online prediction nodes send stderr and stdout streams to Stackdriver Logging
// +kubebuilder:validation:Optional
OnlinePredictionConsoleLogging *bool `json:"onlinePredictionConsoleLogging,omitempty" tf:"online_prediction_console_logging,omitempty"`
// If true, online prediction access logs are sent to StackDriver Logging.
// +kubebuilder:validation:Optional
OnlinePredictionLogging *bool `json:"onlinePredictionLogging,omitempty" tf:"online_prediction_logging,omitempty"`
// The ID of the project in which the resource belongs.
// If it is not provided, the provider project is used.
// +kubebuilder:validation:Optional
Project *string `json:"project,omitempty" tf:"project,omitempty"`
// The list of regions where the model is going to be deployed.
// Currently only one region per model is supported
// +kubebuilder:validation:Optional
Regions []*string `json:"regions,omitempty" tf:"regions,omitempty"`
}
func (*ModelParameters) DeepCopy ¶
func (in *ModelParameters) DeepCopy() *ModelParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelParameters.
func (*ModelParameters) DeepCopyInto ¶
func (in *ModelParameters) DeepCopyInto(out *ModelParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelSpec ¶
type ModelSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ModelParameters `json:"forProvider"`
}
ModelSpec defines the desired state of Model
func (*ModelSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelSpec.
func (*ModelSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelStatus ¶
type ModelStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ModelObservation `json:"atProvider,omitempty"`
}
ModelStatus defines the observed state of Model.
func (*ModelStatus) DeepCopy ¶
func (in *ModelStatus) DeepCopy() *ModelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelStatus.
func (*ModelStatus) DeepCopyInto ¶
func (in *ModelStatus) DeepCopyInto(out *ModelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.